unit display;

{--------------------------------------------------------------------------}

interface

uses
 mtypes;

procedure hidecursor;

procedure restorecursor;

procedure writexy(x,y:integer; text:string);

procedure frame(x1,y1,x2,y2,fg,bg:integer);

procedure inptext(var text:string; x1,x2,y:integer);

function pnum(num:longint):string;

procedure centertext(text:string; y:integer);

function menu(items:itemlist; x1,y1,x2,y2,fg,bg:integer):integer;

procedure clicktext(text:string);

procedure clicktextln(text:string);
{--------------------------------------------------------------------------}

implementation

uses
 crt,dos;

{--------------------------------------------------------------------------}
{hide the cursor}

procedure hidecursor;
var
 regpack:registers;
begin
 with regpack do
  begin
   ax:=$0100;
   cx:=$1000;
  end;
 intr($10,regpack);
end;

{--------------------------------------------------------------------------}
{show the cursor}

procedure restorecursor;
var
 regpack:registers;
begin
 with regpack do
  begin
   ax:=$0100;
   cx:=$0607;
  end;
 intr($10,regpack);
end;

{--------------------------------------------------------------------------}
{write to a specific (X,Y) coordinate}

procedure writexy(x,y:integer; text:string);
begin
 gotoxy(x,y); {move cursor to coordinates}
 write(text); {write the text}
end;

{--------------------------------------------------------------------------}
{print text with clicking}

procedure clicktext(text:string);
begin
 for i:=1 to length(text) do
 begin
  write(text[i]);
  sound(8000);
  delay(10);
  sound(1000);
  nosound;
  delay(75);
 end;
 nosound;
end;

{--------------------------------------------------------------------------}
{print text with clicking and linefeed}

procedure clicktextln(text:string);
begin
 for i:=1 to length(text) do
 begin
  write(text[i]);
  sound(8000);
  delay(10);
  sound(1000);
  nosound;
  delay(75);
 end;
 nosound;
 delay(300);
 writeln;
end;
{--------------------------------------------------------------------------}
{draw a colored text frame}

procedure frame(x1,y1,x2,y2,fg,bg:integer);
var
 x,y:integer;
begin
 textbackground(bg);     {set the background color}
 textcolor(fg);          {set the foreground color}
 gotoxy(x1,y1);
 write('');             {draw the upper left hand corner}
 for x:=x1+1 to x2-1 do  {draw the top line}
  write('');
 write('');             {draw the upper right corner}
 for y:=y1+1 to y2-1 do  {draw the left & right lines while}
 begin                   {filling the middle}
  gotoxy(x1,y);
  write('');
  for x:=x1+1 to x2-1 do
   write(' ');
  gotoxy(x2,y);
  write('');
 end;
 gotoxy(x1,y2);
 write('');             {draw the lower left corner}
 for x:=x1+1 to x2-1 do  {draw the bottom line}
  write('');
 write('');             {draw the lower right corner}
 gotoxy(x1,y1);          {move the cursor to the starting coordinates}
end;

{--------------------------------------------------------------------------}
{do a line input for text}

procedure inptext(var text:string; x1,x2,y:integer);
var
 i,len:integer;
 ch:char;
begin
 restorecursor;
 len:=x2-x1;
 textcolor(YELLOW);
 textbackground(BLACK);
 text[0]:=' ';
 gotoxy(x1,y);
 for i:=1 to len do
  write(' ');
 gotoxy(x1,y);
 ch:=' ';
 i:=1;
 while ch <> Chr(13) do
 begin
  ch:=readkey;
  if ch=Chr(8) then
   if i>=1 then
   begin
    gotoxy(x1+(i-1),y);
    write(' ');
    gotoxy(x1+(i-1),y);
    text[i]:=' ';
    if i<>1 then dec(i);
   end;
  if (ch <> Chr(8)) and (ch <> Chr(13)) and (i < len) then
  begin
   gotoxy(x1+i,y);
   write(ch);
   text[i]:=ch;
   inc(i);
  end;
 end;
 delete(text,i,256);
 hidecursor;
end;

{--------------------------------------------------------------------------}
{pretty an integer in string format for decorative printing}
{ex. 1000000 to "1,000,000"                                }

function pnum(num:longint):string;
var
 i,j:integer;
 t1,t2,t3:string;
begin
 str(num,t1);
 j:=0;
 t2:='                                     ';
 for i:=length(t1) downto 1 do
 begin
  inc(j);
  t2[j]:=t1[i];
  if (((length(t1)-i)+1) MOD 3)=0 then
  begin
   inc(j);
   t2[j]:=',';
  end;
 end;
 delete(t2,pos(' ',t2),255);
 t3:=t2;
 j:=0;
 for i:=length(t2) downto 1 do
 begin
  inc(j);
  t3[j]:=t2[i];
 end;
 pnum:=t3;
end;

{--------------------------------------------------------------------------}
{center a text string}

procedure centertext(text:string; y:integer);
begin
 gotoxy(40-(Length(text) DIV 2),y);
 write(text);
end;

{--------------------------------------------------------------------------}
{implement a menu for use in many areas}

function menu(items:itemlist; x1,y1,x2,y2,fg,bg:integer):integer;
var
 i,numitems:integer;
 ch:char;
begin
 frame(x1,y1,x2,y2,fg,bg);
 numitems:=0;
 repeat
  inc(numitems);
 until items[numitems]='*';
 dec(numitems);
 for i:=1 to numitems do
 begin
  gotoxy(x1+1,y1+i);
  write(i:1,') ',items[i]);
 end;
 i:=1;
 textbackground(GREEN);
 gotoxy(x1+1,y1+1);
 writeln('1) ',items[1],' ':(((x2-x1)-5)-length(items[1])));
 ch:=' ';
 while (ch <> chr(13)) and (ch <> chr(27)) do
 begin
  ch:=readkey;
  if (ch=chr(72)) and (i<>1) then
  begin
   textbackground(bg);
   gotoxy(x1+1,y1+i);
   writeln(i:1,') ',items[i],' ':(((x2-x1)-5)-length(items[i])));
   dec(i);
   textbackground(GREEN);
   gotoxy(x1+1,y1+i);
   writeln(i:1,') ',items[i],' ':(((x2-x1)-5)-length(items[i])));
  end;
  if (ch=chr(80)) and (i<>numitems) then
  begin
   textbackground(bg);
   gotoxy(x1+1,y1+i);
   writeln(i:1,') ',items[i],' ':(((x2-x1)-5)-length(items[i])));
   inc(i);
   textbackground(GREEN);
   gotoxy(x1+1,y1+i);
   writeln(i:1,') ',items[i],' ':(((x2-x1)-5)-length(items[i])));
  end;
  if (ch=chr(27)) then
  begin
   menu:=0;
   exit;
  end;
 end;
 menu:=i;
end;
{--------------------------------------------------------------------------}


end.